@@ -272,7 +272,7 @@ class BeamerMultiFigureSlide( BeamerSlide ):
             text = texts[cIdx]
           except IndexError as e:
             path = text = None
-            logger.warning("Not filling figure at index %d due to: %s", e )
+            self._warning("Not filling figure at index %d due to: %s", e )
           if path:
             try:
               if text and text != ((),):
@@ -448,7 +448,7 @@ class BeamerTexReport( TexObjectCollection ):
         Output_class = PDFTexOutput if self._toPDF else TexSessionStream
         if not self._stream() is None and not isinstance( self._stream(), Output_class ):
           changeStream = True
-          logger.warning("Forcing output to be created by %s despite this class is in the context of %s."
+          self._warning("Forcing output to be created by %s despite this class is in the context of %s."
                        , Output_class, self._stream().__class__ )
       else:
         self._toPDF = True
@@ -484,7 +484,7 @@ class BeamerTexReport( TexObjectCollection ):
   def __exit__(self, exc_type, exc_value, traceback):
     if exc_type:
       import traceback as tb
-      logger.error("Traceback:\n%s\nError occurred: %s", ''.join(tb.format_tb(traceback)), exc_value if exc_value else exc_type)
+      self._error("Traceback:\n%s\nError occurred: %s", ''.join(tb.format_tb(traceback)), exc_value if exc_value else exc_type)
     self._write( self._stream() )
     if hasattr(self._stream(), '_setVia_BeamerTexReport'):
       self._stream().__exit__( exc_type, exc_value, traceback )
